@@ -49,6 +49,7 @@ sub import {
     my $j = Mojo::JSON->new;
     return ref $d ~~ [qw(ARRAY HASH)] ? $j->encode($d) : $j->decode($d);
   };
+  *{"${caller}::n"} = sub { _request($UA->build_json_tx(@_)) };
   *{"${caller}::o"} = sub { _request($UA->build_tx(OPTIONS => @_)) };
   *{"${caller}::p"} = sub { _request($UA->build_tx(POST    => @_)) };
   *{"${caller}::r"} = sub { $UA->app->dumper(@_) };
@@ -130,7 +131,7 @@ resulting L<Mojo::Message::Response> object.
   my $res = f('http://kraih.com' => {a => 'b'});
   my $res = f('kraih.com' => 'UTF-8' => {a => 'b'} => {DNT => 1});
 
-Perform C<POST> form request with L<Mojo::UserAgent/"post_form"> and return
+Perform C<POST> request with L<Mojo::UserAgent/"post_form"> and return
 resulting L<Mojo::Message::Response> object.
 
 =head2 C<g>
@@ -161,6 +162,14 @@ Encode Perl data structure or decode JSON with L<Mojo::JSON>.
 
   $ perl -Mojo -E 'b(j({hello => "world!"}))->spurt("hello.json")'
 
+=head2 C<n>
+
+  my $res = n('http://kraih.com' => {a => 'b'});
+  my $res = n('kraih.com' => {a => 'b'} => {DNT => 1});
+
+Perform C<POST> request with L<Mojo::UserAgent/"post_json"> and return
+resulting L<Mojo::Message::Response> object.
+
 =head2 C<o>
 
   my $res = o('mojolicio.us');
